﻿namespace UltraTabControlCustomGrids
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Data;
    using System.Diagnostics;
    using System.Drawing;
    using System.Linq;
    using System.Text;
    using System.Windows.Forms;
    using Infragistics.Win.UltraWinGrid;
    using Infragistics.Win.UltraWinTabControl;

    public partial class Form1 : Form
    {
        private DataSet dataSet;
        private int tabsCount;
        private int rows;
        private int cols;
        private DateTime now;

        public Form1()
        {
            this.InitializeComponent();
            this.tabsCount = 5;
            this.rows = 100;
            this.cols = 5;
            this.now = DateTime.Today;

            this.dataSet = this.GetDataSet(this.tabsCount);
            this.SetComboData(this.comboBox1);
            this.SetComboData(this.comboBox2);
        }

        private DataSet GetDataSet(int tabs)
        {
            DataSet ds = new DataSet();
            ds.Tables.Add(this.GetTabsDataTable(tabs));
            ds.Tables.Add(this.GetGridDataTable(this.rows, this.cols));

            return ds;
        }

        private DataTable GetTabsDataTable(int tabs)
        {
            DataTable tabsTable = new DataTable("Tabs");
            tabsTable.Columns.Add("Id", typeof(int)).AutoIncrement = true;
            tabsTable.Columns.Add("Tag", typeof(DateTime));

            for (int tab = 0; tab < tabs; tab++)
            {
                tabsTable.Rows.Add(new object[] { null, this.now.AddDays(tab) });
            }

            return tabsTable;
        }

        private DataTable GetGridDataTable(int rows, int cols)
        {
            DataTable dt = new DataTable("GridData");

            for (int col = 0; col < cols; col++)
            {
                dt.Columns.Add(string.Format("Column #{0}", col + 1), typeof(DateTime));
            }

            for (int row = 0; row < rows; row++)
            {
                DataRow addRow = dt.NewRow();
                foreach (DataColumn column in dt.Columns)
                {
                    addRow[column] = this.now.AddDays(row % (column.Ordinal + 4));
                }

                dt.Rows.Add(addRow);
            }

            return dt;
        }

        private void SetComboData(ComboBox comboBox)
        {
            for (int row = 0; row < this.tabsCount; row++)
            {
                comboBox.Items.Add(this.now.AddDays(row));
            }
        }

        private void ButtonGetTabs_Click(object sender, EventArgs e)
        {
            DataTable tabsTable = this.dataSet.Tables["Tabs"];
            foreach (DataRow row in tabsTable.Rows)
            {
                UltraTabPageControl tabPage = new UltraTabPageControl();
                tabPage.Location = new Point(-10000, -10000);
                tabPage.Size = new Size(
                    this.ultraTabControl1.Size.Width - 4,
                    this.ultraTabControl1.Size.Height - 50);

                string tabName = string.Format("Tab #{0}", row.ItemArray[0].ToString());
                object tag = row.ItemArray[1];

                UltraTab tab = new UltraTab();
                tab.TabPage = tabPage;
                tab.Text = tabName;
                tab.Tag = tag;
                this.ultraTabControl1.Tabs.AddRange(new UltraTab[] { tab });
                this.ultraTabControl1.Controls.Add(tabPage);

                ComboBox cb = new ComboBox();
                cb.FormattingEnabled = true;
                cb.Dock = DockStyle.Top;
                cb.Name = "nonSharedCombo";
                cb.Size = new Size(0, 21);
                this.SetComboData(cb);
                cb.SelectedIndexChanged += this.ComboBox_SelectedIndexChanged;
                tabPage.Controls.Add(cb);

                UltraGrid grid = new UltraGrid();
                grid.Name = "Grid";
                grid.Size = new Size(0, 250);
                grid.Dock = DockStyle.Top;
                grid.DataSource = this.dataSet.Tables["GridData"];
                tabPage.Controls.Add(grid);
            }

            this.ultraTabControl1.Tabs[0].Selected = true;
        }

        private void UltraTabControl1_SelectedTabChanging(object sender, SelectedTabChangingEventArgs e)
        {
            DateTime tagFilter = (DateTime)e.Tab.Tag;
            UltraGrid grid = (UltraGrid)e.Tab.TabPage.Controls.Find("Grid", true)[0];
            this.ApplyGridFilter(tagFilter, grid, 4);

            ComboBox nonSharedCombo = (ComboBox)e.Tab.TabPage.Controls.Find("nonSharedCombo", true)[0];
            if (!string.IsNullOrWhiteSpace(nonSharedCombo.Text))
            {
                DateTime nonSharedComboFilterDate = DateTime.Parse(nonSharedCombo.Text);
                this.ApplyGridFilter(nonSharedComboFilterDate, grid, 1);
            }

            if (!string.IsNullOrWhiteSpace(this.comboBox1.Text))
            {
                DateTime combo1FilterDate = DateTime.Parse(this.comboBox1.Text);
                this.ApplyGridFilter(combo1FilterDate, grid, 2);
            }

            if (!string.IsNullOrWhiteSpace(this.comboBox2.Text))
            {
                DateTime combo2FilterDate = DateTime.Parse(this.comboBox2.Text);
                this.ApplyGridFilter(combo2FilterDate, grid, 3);
            }   
        }

        private void ComboBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            ComboBox cb = sender as ComboBox;
            if (cb != null)
            {
                DateTime filterDate = DateTime.Parse(cb.Text);
                UltraGrid grid = (UltraGrid)this.ultraTabControl1.SelectedTab.TabPage.Controls.Find("Grid", true)[0];

                switch (cb.Name)
                {
                    case "nonSharedCombo":
                        this.ApplyGridFilter(filterDate, grid, 1);
                        break;
                    case "comboBox1":
                        this.ApplyGridFilter(filterDate, grid, 2);
                        break;
                    case "comboBox2":
                        this.ApplyGridFilter(filterDate, grid, 3);
                        break;
                    default:
                        break;
                }
            }
        }

        private void ApplyGridFilter(DateTime tagFilter, UltraGrid grid, int colIndex)
        {
            grid.DisplayLayout.Bands[0].ColumnFilters[colIndex].ClearFilterConditions();
            grid.DisplayLayout.Bands[0].ColumnFilters[colIndex].FilterConditions.Add(FilterComparisionOperator.Equals, tagFilter);
        }
    }
}
